import type { IGomokuContext } from './context.type';
import { GomokuStateCache } from './state-cache';
import type { IGomokuState } from './state.type';
import type { IGomokuCandidateState, IGomokuPiece, IScoreMap } from './types';
export interface IGomokuSolutionProps {
    MAX_ROW: number;
    MAX_COL: number;
    MAX_ADJACENT?: number;
    MAX_DEPTH?: number;
    MAX_DISTANCE_OF_NEIGHBOR?: number;
    MAX_NEXT_MOVER_BUFFER?: number;
    POSSIBILITY_SEARCH_EQUIV_CANDIDATE?: number;
    scoreMap?: IScoreMap;
}
export declare class GomokuSolution {
    readonly MAX_DEPTH: number;
    readonly POSSIBILITY_SEARCH_EQUIV_CANDIDATE: number;
    readonly context: IGomokuContext;
    readonly state: IGomokuState;
    protected readonly _cache: GomokuStateCache;
    protected readonly _queues: IGomokuCandidateState[][];
    protected _bestMoveId: number;
    protected _mainPlayerId: number;
    constructor(props: IGomokuSolutionProps);
    init(pieces: ReadonlyArray<IGomokuPiece>): void;
    forward(r: number, c: number, playerId: number): void;
    revert(r: number, c: number): void;
    minimaxSearch(nextPlayer: number): [r: number, c: number];
    protected _alphaBeta(player: number, alpha: number, beta: number, cur: number, prevState: bigint): number;
    protected _forward(posId: number, playerId: number): void;
    protected _revert(posId: number): void;
}
