import type { GomokuDirectionType } from './constant';
import type { IGomokuContext } from './context.type';
import type { IGomokuCountMap } from './count-map.type';
import type { IGomokuState } from './state.type';
import type { IGomokuCandidateState, IGomokuPiece, IScoreMap } from './types';
declare type ICountOfReachLimits = [count0: number, count1: number];
declare type IStateScores = [score0: number, score1: number];
export interface IGomokuStateProps {
    context: IGomokuContext;
    scoreMap: IScoreMap;
    MAX_NEXT_MOVER_BUFFER: number;
}
export declare class GomokuState implements IGomokuState {
    readonly MAX_NEXT_MOVER_BUFFER: number;
    readonly context: IGomokuContext;
    protected readonly _countMap: IGomokuCountMap;
    protected readonly _scoreMap: IScoreMap;
    protected readonly _countOfReachLimits: ICountOfReachLimits;
    protected readonly _countOfReachLimitsDirMap: number[][][];
    protected readonly _stateScoreMap: IStateScores;
    protected readonly _stateScoreDirMap: number[][][];
    protected readonly _candidateSet: Set<number>;
    protected readonly _candidateScoreMap: number[][];
    protected readonly _candidateScoreDirMap: number[][][];
    protected readonly _candidateScoreExpired: number[];
    protected _nextMoverBufferFac: number;
    constructor(props: IGomokuStateProps);
    init(pieces: ReadonlyArray<IGomokuPiece>): void;
    forward(posId: number): void;
    revert(posId: number): void;
    expand(nextPlayerId: number, candidates: IGomokuCandidateState[]): void;
    score(currentPlayer: number, scoreForPlayer: number): number;
    reRandNextMoverBuffer(): void;
    isWin(currentPlayer: number): boolean;
    isDraw(): boolean;
    isFinal(): boolean;
    protected _updateStateScore(posId: number): void;
    protected _expireCandidates(posId: number): void;
    protected _evaluateCandidate(posId: number, nextPlayerId: number): number;
    protected _evaluateScoreInDirection(startPosId: number, dirType: GomokuDirectionType): {
        scores: IStateScores;
        countOfReachLimits: ICountOfReachLimits;
    };
    protected _forward(posId: number, playerId: number): void;
    protected _revert(posId: number): void;
}
export {};
